@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2022-2025 the Eask authors.
+ * Copyright (C) 2022-2026 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['workspace', '.eask'];
-exports.desc = 'Clean up .eask directory';
+exports.desc = 'Clean up the .eask directory';
 
 exports.handler = async (argv) => {
   await UTIL.e_call(argv, 'clean/workspace');
