@@ -197,7 +197,8 @@ workspace has no valid Eask-file; it will load global workspace instead."
                     "create/package" "create/elpa" "create/el-project"
                     "bump" "cat" "keywords" "repl"
                     "generate/ignore" "generate/license"
-                    "test/melpazoid")))
+                    "test/melpazoid"
+                    "util/root")))
 
 (defun eask-execution-p ()
   "Return t if the command is the execution command.
@@ -207,7 +208,7 @@ This is added because we don't want to pollute `error' and `warn' functions."
                     "run/script" "run/command"
                     ;; NOTE: These test commands handle the exit code themselves;
                     ;; therefore, we don't need to handle it for them!
-                    "test/ert" "test/ert-runner")))
+                    "test/ert" "test/ert-runner" "test/buttercup")))
 
 (defun eask-checker-p ()
   "Return t if running Eask as the checker.
@@ -611,11 +612,14 @@ Arguments FNC and ARGS are used for advice `:around'."
 
 (defun eask--update-exec-path ()
   "Add all bin directory to the variable `exec-path'."
-  (dolist (entry (directory-files package-user-dir t directory-files-no-dot-files-regexp))
-    (when-let* ((bin (expand-file-name "bin" entry))
-                ((file-directory-p bin)))
-      (add-to-list 'exec-path bin t)))
-  (delete-dups exec-path))
+  (when-let* (((file-exists-p package-user-dir))
+              (entries (directory-files package-user-dir
+                                        t directory-files-no-dot-files-regexp)))
+    (dolist (entry entries)
+      (when-let* ((bin (expand-file-name "bin" entry))
+                  ((file-directory-p bin)))
+        (add-to-list 'exec-path bin t)))
+    (delete-dups exec-path)))
 
 (defun eask--update-load-path ()
   "Add all .el files to the variable `load-path'."
@@ -701,7 +705,8 @@ scope of the dependencies (it's either `production' or `development')."
   (eask-with-progress
     (ansi-green "Updating environment variables... ")
     (eask-with-verbosity 'debug
-      (eask--update-exec-path) (eask--update-load-path)
+      (eask--update-exec-path)
+      (eask--update-load-path)
       (setenv "PATH" (string-join exec-path path-separator))
       (setenv "EMACSLOADPATH" (string-join load-path path-separator)))
     (ansi-green "done ✓")))
@@ -1384,6 +1389,8 @@ This uses function `locate-dominating-file' to look up directory tree."
                  (eask-msg "✗ Loading config Eask file... missing!"))
                (eask-msg ""))
              (package-activate-all)
+             (ignore-errors (make-directory package-user-dir t))
+             (eask--silent (eask-setup-paths))
              (eask--load-config)
              (eask--with-hooks ,@body)))
           ((eask-global-p)
@@ -1399,6 +1406,7 @@ This uses function `locate-dominating-file' to look up directory tree."
                  (eask-msg ""))
                (package-activate-all)
                (ignore-errors (make-directory package-user-dir t))
+               (eask--silent (eask-setup-paths))
                (eask-with-verbosity 'debug (eask--load-config))
                (eask--with-hooks ,@body))))
           ((eask-special-p)  ; Commands without Eask-file needed!
@@ -1418,6 +1426,7 @@ This uses function `locate-dominating-file' to look up directory tree."
                  (eask-msg ""))
                (package-activate-all)
                (ignore-errors (make-directory package-user-dir t))
+               (eask--silent (eask-setup-paths))
                (eask-with-verbosity 'debug (eask--load-config))
                (eask--with-hooks ,@body))))
           (t
